<?php
/**
 * JulioReis_CorreiosFollowup
 *
 * Do not edit this file if you want to update this module for future new versions.
 *
 * @category  JulioReis
 * @package   JulioReis_CorreiosFollowup
 *
 * @copyright Copyright (c) 2018 Julio Reis (www.rapidets.com.br)
 *
 * @author    Julio Reis <julioreis.si@gmail.com>
 */

namespace JulioReis\CorreiosFollowup\Model;

class Service
{
    private $domDocumentFactory;
    private $domXPathFactory;

    public function __construct(
        \DOMDocumentFactory $domDocumentFactory,
        \DomXPathFactory $domXPathFactory
    ) {
        $this->domDocumentFactory = $domDocumentFactory;
        $this->domXPathFactory = $domXPathFactory;
    }

    /**
     * @param $codigoRastreio
     * @return array
     */
    public function getTrackingStatuses($codigoRastreio)
    {
        $url = 'http://www2.correios.com.br/sistemas/rastreamento/ctrl/ctrlRastreamento.cfm?';
        $post = ("acao=&objetos={$codigoRastreio}");
        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
        curl_setopt($ch, CURLOPT_COOKIEFILE, '/tmp/cookie.txt');
        curl_setopt($ch, CURLOPT_COOKIEJAR, '/tmp/cookie.txt');
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($ch, CURLOPT_REFERER, $url);
        $content = curl_exec($ch);
        curl_close($ch);

        $dom = $this->domDocumentFactory->create();
        @$dom->loadHTML($content);

        $listDates = $this->getElementsByClassName($dom, 'sroDtEvent');

        $trackingLines = [];
        foreach ($listDates as $event) {
            $trackingLines[][0] = $this->formatString($event->nodeValue);
        }

        $listStatuses = $this->getElementsByClassName($dom, 'sroLbEvent');

        $index = 0;
        foreach ($listStatuses as $event) {
            $trackingLines[$index][1] = $this->formatString($event->nodeValue);
            $index++;
        }
        return $trackingLines;
    }

    /**
     * @param $dom
     * @param $className
     * @return \DOMNodeList
     */
    private function getElementsByClassName($dom, $className)
    {
        $finder = $this->domXPathFactory->create(
            [
                'doc' => $dom
            ]
        );
        return $finder->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' $className ')]");
    }

    /**
     * @param $str
     * @return string
     */
    private function formatString($str)
    {
        return ltrim(rtrim(str_replace("\r", '', $str)));
    }
}
